#!/bin/sh
# This script must be able to run on busybox-powered devices, so uses POSIX shell instead of bash.

set -e #< Exit on error.

CUSTOMIZATION="networkoptix"
DISTRIB="nxgo-server-5.1.4.38690-linux_arm64.hanwha_edge1"

INSTALL_DIR="/opt/${CUSTOMIZATION}"
MODULE_DIR="${INSTALL_DIR}/mediaserver"
TAR_FILE="./${DISTRIB}.tar.gz"

CONTROL_SCRIPT="${INSTALL_DIR}/mediaserver/bin/mediaserver.sh"

upgrade_vms()
{
    if [ -f "${CONTROL_SCRIPT}" ]; then
        if "${CONTROL_SCRIPT}" status >/dev/null 2>&1; then
            was_running="1"
            "${CONTROL_SCRIPT}" stop
        else
            was_running="0"
        fi
    else
        was_running="0"
    fi

    rm -rf "${MODULE_DIR}/lib"
    rm -rf "${MODULE_DIR}/bin/plugins"
    rm -rf "${MODULE_DIR}/bin/plugins_optional"
    mkdir -p "${INSTALL_DIR}"
    tar xfv "${TAR_FILE}" --dereference --directory "/"

    mkdir -p "${INSTALL_DIR}/mediaserver/etc"

    "${INSTALL_DIR}/mediaserver/bin/upgrade_config.sh" \
        "${INSTALL_DIR}/mediaserver/etc/mediaserver.conf" \
        "${INSTALL_DIR}/mediaserver/share/configs/mediaserver.conf" \
        "${INSTALL_DIR}/mediaserver/etc/mediaserver_conf_added_keys.txt" \
        "${INSTALL_DIR}/mediaserver/bin/config_helper.sh"

    if [ "${was_running}" = "1" ]; then
        "${CONTROL_SCRIPT}" start
    fi
}

main()
{
    if [ ! -z "$1" ]; then
        upgrade_vms >>"$1" 2>&1
    else
        upgrade_vms 2>&1
    fi
}

main "$@"
